import numpy as np

def train(data):
    d = np.array(data)[:,:-1]
    target = np.array(data)[:,-1]

    print("\n The attributes are: ", d)
    print("\n The target is: ", target)

    def train(c, t):
        for i, val in enumerate(t):
            if val == "Yes":
                specific_hypothesis = c[i].copy()
                break

        for i, val in enumerate(c):
            if t[i] == "Yes":
                for x in range(len(specific_hypothesis)):
                    if val[x] != specific_hypothesis[x]:
                        specific_hypothesis[x] = '?'

        return specific_hypothesis

    print("\n The final hypothesis is:", train(d, target))


import os
import pandas as pd
from .trainer import train

def load_data():
    current_dir = os.path.dirname(__file__)
    data = pd.read_csv(os.path.join(current_dir, 'data.csv'))
    print(data, "\n")
    train(data)


from setuptools import setup, find_packages

setup(
    name='salgo',
    version='0.2',
    packages=find_packages(),
    include_package_data=True,
    package_data={'': ['data.csv']},
    install_requires=[
        'pandas',
        'numpy',
    ],
    author='Raghul',
    author_email='raghulares@gmail.com',
    description='A package for S algorithm implementation with datasets included.'
)